@@ -131,7 +131,7 @@ class Utils(object):
 
 		client = docker.from_env()
 		cls.last_time_docker_login = cls.get_timestamp()
-		"""
+		
 		cls.last_time_docker_login = cls.get_timestamp()
 		client = docker.from_env()
 		try:
@@ -140,7 +140,8 @@ class Utils(object):
 		except Exception as e:
 			raise DockerError('Login to docker failed: ' + str(e), None)
 
-		return client
+		"""
+		return docker.from_env()
 
 	@classmethod
 	def docker_pull_image(cls, docker_client, image):
